/* OpenDoors 6.00
 * (C) Copyright 1991 - 1996 by Brian Pirie. All Rights Reserved.
 *
 *
 *        File: ODInQue.h
 *
 * Description: OpenDoors input queue management. This input queue is where
 *              all input events (e.g. keystrokes) from both local and remote
 *              systems are combined into a single stream.
 *
 *   Revisions: Date          Ver   Who  Change
 *              ---------------------------------------------------------------
 *              Nov 16, 1995  5.10  BP   Created.
 *              Jan 04, 1996  5.10  BP   Moved event type defs to OpenDoor.h.
 *              Jan 04, 1996  5.10  BP   tODInQueueEvent -> tODInputEvent.
 *              Jan 30, 1996  5.10  BP   Add ODInQueueGetNextEvent() timeout.
 *              Feb 19, 1996  6.00  BP   Changed version number to 6.00.
 */

#ifndef _INC_ODINQUE
#define _INC_ODINQUE

#include <time.h>

#include "ODTypes.h"

/* OpenDoors input queue handle. */
typedef tODHandle tODInQueueHandle;

/* Input queue functions. */
tODResult ODInQueueAlloc(tODInQueueHandle *phInQueue,  INT nInitialQueueSize);
void ODInQueueFree(tODInQueueHandle hInQueue);
BOOL ODInQueueWaiting(tODInQueueHandle hInQueue);
tODResult ODInQueueAddEvent(tODInQueueHandle hInQueue,
   tODInputEvent *pEvent);
tODResult ODInQueueGetNextEvent(tODInQueueHandle hInQueue,
   tODInputEvent *pEvent, tODMilliSec Timeout);
void ODInQueueEmpty(tODInQueueHandle hInQueue);
time_t ODInQueueGetLastActivity(tODInQueueHandle hInQueue);
void ODInQueueResetLastActivity(tODInQueueHandle hInQueue);

#endif /* _INC_ODINQUE */
